@@ -50,7 +50,6 @@ class BinaryClassifier(Classifier):
         return (self.score_predictor(X) >= self.threshold).astype(int)
 
 
-# TODO - WARNING - THERE'S SOME BUG IN THIS CLASSIFIER!
 class BinaryClassifierAtROCDiagonal(Classifier):
     """A dummy classifier whose predictions have no correlation with the input
     features, but achieves whichever target FPR or TPR you want (on ROC diag.)
@@ -295,6 +294,16 @@ class RandomizedClassifier(Classifier):
         target_fpr, target_tpr = target_roc_point
         fpr, tpr, thrs = roc_curve_data
 
+        # Check if we have more than two ROC points
+        # (3 minimum to compute convex hull)
+        if len(fpr) <= 1:
+            raise ValueError(f"Invalid ROC curve data for classifier: fpr:{fpr}; tpr:{tpr};")
+
+        if len(fpr) == 2:
+            logging.warning(f"Got ROC data with only 2 points: producing a random classifier...")
+            assert np.isclose(target_roc_point[0], target_roc_point[1])
+            return BinaryClassifierAtROCDiagonal(target_fpr=target_roc_point[0])
+
         # Compute hull of ROC curve
         roc_curve_points = np.stack((fpr, tpr), axis=1)
         hull = ConvexHull(roc_curve_points)
@@ -325,8 +334,8 @@ class RandomizedClassifier(Classifier):
         )
 
         if max(weights) > 1:
+            logging.error(f"This should never happen; got weights over 100%: w={weights}")
             import ipdb; ipdb.set_trace()
-            # BUG this should never happen!
 
         # Instantiate classifiers for points A and B
         clf_a = BinaryClassifier(predictor, threshold=thrs[point_A_idx])
