@@ -151,7 +151,7 @@ class RelaxedEqualOdds(Classifier):
         logging.info(
             f"Maximum fairness violation is between "
             f"group={groupA} (p={self.groupwise_roc_points[groupA]}) and "
-            f"group={groupB} (p={self.groupwise_roc_points[groupB]}) and "
+            f"group={groupB} (p={self.groupwise_roc_points[groupB]});"
         )
 
         return max_violation
